Index: branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/Core.cs
===================================================================
--- branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/Core.cs	(revision 6712)
+++ branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/Core.cs	(revision 6721)
@@ -29,4 +29,5 @@
 using HeuristicLab.Common;
 using HeuristicLab.Core;
+using TS = System.Threading.Tasks;
 
 
@@ -148,5 +149,5 @@
     /// <param name="container">The container, containing the message</param>
     private void DetermineAction(MessageContainer container) {
-      clientCom.LogMessage(string.Format("Message: {0} for job: {1} ", container.Message.ToString(), container.JobId));
+      clientCom.LogMessage(string.Format("Message: {0} for job: {1} ", container.Message.ToString(), container.TaskId));
 
       if (container is ExecutorMessageContainer<Guid>) {
@@ -156,14 +157,14 @@
         switch (container.Message) {
           case MessageContainer.MessageType.CalculateJob:
-            CalculateJobAsync(container.JobId);
+            CalculateJobAsync(container.TaskId);
             break;
           case MessageContainer.MessageType.AbortJob:
-            AbortJobAsync(container.JobId);
+            AbortJobAsync(container.TaskId);
             break;
           case MessageContainer.MessageType.StopJob:
-            StopJobAsync(container.JobId);
+            StopJobAsync(container.TaskId);
             break;
           case MessageContainer.MessageType.PauseJob:
-            PauseJobAsync(container.JobId);
+            PauseJobAsync(container.TaskId);
             break;
           case MessageContainer.MessageType.StopAll:
@@ -195,5 +196,5 @@
 
     private void CalculateJobAsync(Guid jobId) {
-      Task.Factory.StartNew(HandleCalculateJob, jobId)
+      TS.Task.Factory.StartNew(HandleCalculateJob, jobId)
       .ContinueWith((t) => {
         SlaveStatusInfo.IncrementExceptionOccured();
@@ -203,5 +204,5 @@
 
     private void StopJobAsync(Guid jobId) {
-      Task.Factory.StartNew(HandleStopJob, jobId)
+      TS.Task.Factory.StartNew(HandleStopJob, jobId)
        .ContinueWith((t) => {
          SlaveStatusInfo.IncrementExceptionOccured();
@@ -211,5 +212,5 @@
 
     private void PauseJobAsync(Guid jobId) {
-      Task.Factory.StartNew(HandlePauseJob, jobId)
+      TS.Task.Factory.StartNew(HandlePauseJob, jobId)
        .ContinueWith((t) => {
          SlaveStatusInfo.IncrementExceptionOccured();
@@ -219,5 +220,5 @@
 
     private void AbortJobAsync(Guid jobId) {
-      Task.Factory.StartNew(HandleAbortJob, jobId)
+      TS.Task.Factory.StartNew(HandleAbortJob, jobId)
        .ContinueWith((t) => {
          SlaveStatusInfo.IncrementExceptionOccured();
@@ -228,5 +229,5 @@
     private void HandleCalculateJob(object jobIdObj) {
       Guid jobId = (Guid)jobIdObj;
-      Job job = null;
+      Task job = null;
       int usedCores = 0;
       try {
@@ -236,7 +237,7 @@
         if (ConfigManager.GetFreeMemory() < job.MemoryNeeded) throw new OutOfMemoryException();
         SlaveStatusInfo.IncrementUsedCores(job.CoresNeeded); usedCores = job.CoresNeeded;
-        JobData jobData = wcfService.GetJobData(jobId);
+        TaskData jobData = wcfService.GetJobData(jobId);
         if (jobData == null) throw new JobDataNotFoundException(jobId);
-        job = wcfService.UpdateJobState(jobId, JobState.Calculating, null);
+        job = wcfService.UpdateJobState(jobId, TaskState.Calculating, null);
         if (job == null) throw new JobNotFoundException(jobId);
         jobManager.StartJobAsync(job, jobData);
@@ -255,14 +256,14 @@
       }
       catch (OutOfCoresException) {
-        wcfService.UpdateJobState(jobId, JobState.Waiting, "No more cores available");
+        wcfService.UpdateJobState(jobId, TaskState.Waiting, "No more cores available");
         throw;
       }
       catch (OutOfMemoryException) {
-        wcfService.UpdateJobState(jobId, JobState.Waiting, "No more memory available");
+        wcfService.UpdateJobState(jobId, TaskState.Waiting, "No more memory available");
         throw;
       }
       catch (Exception e) {
         SlaveStatusInfo.DecrementUsedCores(usedCores);
-        wcfService.UpdateJobState(jobId, JobState.Waiting, e.ToString()); // unknown internal error - report and set waiting again
+        wcfService.UpdateJobState(jobId, TaskState.Waiting, e.ToString()); // unknown internal error - report and set waiting again
         throw;
       }
@@ -272,5 +273,5 @@
       Guid jobId = (Guid)jobIdObj;
       try {
-        Job job = wcfService.GetJob(jobId);
+        Task job = wcfService.GetJob(jobId);
         if (job == null) throw new JobNotFoundException(jobId);
         jobManager.StopJobAsync(jobId);
@@ -290,5 +291,5 @@
       Guid jobId = (Guid)jobIdObj;
       try {
-        Job job = wcfService.GetJob(jobId);
+        Task job = wcfService.GetJob(jobId);
         if (job == null) throw new JobNotFoundException(jobId);
         jobManager.PauseJobAsync(jobId);
@@ -318,7 +319,7 @@
     private void RegisterJobManagerEvents() {
       this.jobManager.JobStarted += new EventHandler<EventArgs<SlaveJob>>(jobManager_JobStarted);
-      this.jobManager.JobPaused += new EventHandler<EventArgs<SlaveJob, JobData>>(jobManager_JobPaused);
-      this.jobManager.JobStopped += new EventHandler<EventArgs<SlaveJob, JobData>>(jobManager_JobStopped);
-      this.jobManager.JobFailed += new EventHandler<EventArgs<Tuple<SlaveJob, JobData, Exception>>>(jobManager_JobFailed);
+      this.jobManager.JobPaused += new EventHandler<EventArgs<SlaveJob, TaskData>>(jobManager_JobPaused);
+      this.jobManager.JobStopped += new EventHandler<EventArgs<SlaveJob, TaskData>>(jobManager_JobStopped);
+      this.jobManager.JobFailed += new EventHandler<EventArgs<Tuple<SlaveJob, TaskData, Exception>>>(jobManager_JobFailed);
       this.jobManager.ExceptionOccured += new EventHandler<EventArgs<SlaveJob, Exception>>(jobManager_ExceptionOccured);
       this.jobManager.JobAborted += new EventHandler<EventArgs<SlaveJob>>(jobManager_JobAborted);
@@ -329,13 +330,13 @@
     }
 
-    private void jobManager_JobPaused(object sender, EventArgs<SlaveJob, JobData> e) {
+    private void jobManager_JobPaused(object sender, EventArgs<SlaveJob, TaskData> e) {
       try {
         SlaveStatusInfo.DecrementUsedCores(e.Value.CoresNeeded);
         heartbeatManager.AwakeHeartBeatThread();
-        Job job = wcfService.GetJob(e.Value.JobId);
+        Task job = wcfService.GetJob(e.Value.JobId);
         if (job == null) throw new JobNotFoundException(e.Value.JobId);
         job.ExecutionTime = e.Value.ExecutionTime;
-        JobData jobData = e.Value.GetJobData();
-        wcfService.UpdateJobData(job, jobData, configManager.GetClientInfo().Id, JobState.Paused);
+        TaskData jobData = e.Value.GetJobData();
+        wcfService.UpdateJobData(job, jobData, configManager.GetClientInfo().Id, TaskState.Paused);
       }
       catch (JobNotFoundException ex) {
@@ -347,13 +348,13 @@
     }
 
-    private void jobManager_JobStopped(object sender, EventArgs<SlaveJob, JobData> e) {
+    private void jobManager_JobStopped(object sender, EventArgs<SlaveJob, TaskData> e) {
       try {
         SlaveStatusInfo.DecrementUsedCores(e.Value.CoresNeeded);
         heartbeatManager.AwakeHeartBeatThread();
-        Job job = wcfService.GetJob(e.Value.JobId);
+        Task job = wcfService.GetJob(e.Value.JobId);
         if (job == null) throw new JobNotFoundException(e.Value.JobId);
         job.ExecutionTime = e.Value.ExecutionTime;
-        JobData jobData = e.Value.GetJobData();
-        wcfService.UpdateJobData(job, jobData, configManager.GetClientInfo().Id, JobState.Finished);
+        TaskData jobData = e.Value.GetJobData();
+        wcfService.UpdateJobData(job, jobData, configManager.GetClientInfo().Id, TaskState.Finished);
       }
       catch (JobNotFoundException ex) {
@@ -365,19 +366,19 @@
     }
 
-    private void jobManager_JobFailed(object sender, EventArgs<Tuple<SlaveJob, JobData, Exception>> e) {
+    private void jobManager_JobFailed(object sender, EventArgs<Tuple<SlaveJob, TaskData, Exception>> e) {
       try {
         SlaveStatusInfo.DecrementUsedCores(e.Value.Item1.CoresNeeded);
         heartbeatManager.AwakeHeartBeatThread();
         SlaveJob slaveJob = e.Value.Item1;
-        JobData jobData = e.Value.Item2;
+        TaskData jobData = e.Value.Item2;
         Exception exception = e.Value.Item3;
 
-        Job job = wcfService.GetJob(slaveJob.JobId);
+        Task job = wcfService.GetJob(slaveJob.JobId);
         if (job == null) throw new JobNotFoundException(slaveJob.JobId);
         job.ExecutionTime = slaveJob.ExecutionTime;
         if (jobData != null) {
-          wcfService.UpdateJobData(job, jobData, configManager.GetClientInfo().Id, JobState.Failed, exception.ToString());
+          wcfService.UpdateJobData(job, jobData, configManager.GetClientInfo().Id, TaskState.Failed, exception.ToString());
         } else {
-          wcfService.UpdateJobState(job.Id, JobState.Failed, exception.ToString());
+          wcfService.UpdateJobState(job.Id, TaskState.Failed, exception.ToString());
         }
         clientCom.LogMessage(exception.Message);
@@ -398,5 +399,5 @@
       heartbeatManager.AwakeHeartBeatThread();
       clientCom.LogMessage(string.Format("Exception occured for job {0}: {1}", e.Value.JobId, e.Value2.ToString()));
-      wcfService.UpdateJobState(e.Value.JobId, JobState.Waiting, e.Value2.ToString());
+      wcfService.UpdateJobState(e.Value.JobId, TaskState.Waiting, e.Value2.ToString());
     }
 
Index: branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/Exceptions/JobAlreadyRunningException.cs
===================================================================
--- branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/Exceptions/JobAlreadyRunningException.cs	(revision 6712)
+++ branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/Exceptions/JobAlreadyRunningException.cs	(revision 6721)
@@ -24,5 +24,5 @@
 namespace HeuristicLab.Clients.Hive.SlaveCore {
   public class JobAlreadyRunningException : Exception {
-    public JobAlreadyRunningException(Guid jobId) : base(string.Format("Job with Id {0} is already running.", jobId)) { }
+    public JobAlreadyRunningException(Guid jobId) : base(string.Format("Task with Id {0} is already running.", jobId)) { }
   }
 }
Index: branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/Exceptions/JobFailedException.cs
===================================================================
--- branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/Exceptions/JobFailedException.cs	(revision 6712)
+++ branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/Exceptions/JobFailedException.cs	(revision 6721)
@@ -24,5 +24,5 @@
 namespace HeuristicLab.Clients.Hive.SlaveCore {
   public class JobFailedException : Exception {
-    public JobFailedException(string reason) : base(string.Format("Job failed with reason: {0}", reason)) { }
+    public JobFailedException(string reason) : base(string.Format("Task failed with reason: {0}", reason)) { }
   }
 }
Index: branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/Exceptions/JobNotDataFoundException.cs
===================================================================
--- branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/Exceptions/JobNotDataFoundException.cs	(revision 6712)
+++ branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/Exceptions/JobNotDataFoundException.cs	(revision 6721)
@@ -24,5 +24,5 @@
 namespace HeuristicLab.Clients.Hive.SlaveCore {
   public class JobDataNotFoundException : Exception {
-    public JobDataNotFoundException(Guid jobId) : base(string.Format("JobData with JobId {0} was not found on server.", jobId)) { }
+    public JobDataNotFoundException(Guid jobId) : base(string.Format("TaskData with TaskId {0} was not found on server.", jobId)) { }
   }
 }
Index: branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/Exceptions/JobNotFoundException.cs
===================================================================
--- branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/Exceptions/JobNotFoundException.cs	(revision 6712)
+++ branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/Exceptions/JobNotFoundException.cs	(revision 6721)
@@ -24,5 +24,5 @@
 namespace HeuristicLab.Clients.Hive.SlaveCore {
   public class JobNotFoundException : Exception {
-    public JobNotFoundException(Guid jobId) : base (string.Format("Job with Id {0} was not found on server.", jobId)) { }
+    public JobNotFoundException(Guid jobId) : base (string.Format("Task with Id {0} was not found on server.", jobId)) { }
   }
 }
Index: branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/Exceptions/JobNotRunningException.cs
===================================================================
--- branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/Exceptions/JobNotRunningException.cs	(revision 6712)
+++ branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/Exceptions/JobNotRunningException.cs	(revision 6721)
@@ -24,5 +24,5 @@
 namespace HeuristicLab.Clients.Hive.SlaveCore {
   public class JobNotRunningException : Exception {
-    public JobNotRunningException(Guid jobId) : base(string.Format("Job with Id {0} is not running.", jobId)) { }
+    public JobNotRunningException(Guid jobId) : base(string.Format("Task with Id {0} is not running.", jobId)) { }
   }
 }
Index: branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/JobStatus.cs
===================================================================
--- branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/JobStatus.cs	(revision 6712)
+++ branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/JobStatus.cs	(revision 6721)
@@ -27,5 +27,5 @@
   public class JobStatus {
     /// <summary>
-    /// Id of the Job
+    /// Id of the Task
     /// </summary>
     [DataMember]
Index: branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/Manager/JobManager.cs
===================================================================
--- branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/Manager/JobManager.cs	(revision 6712)
+++ branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/Manager/JobManager.cs	(revision 6721)
@@ -65,6 +65,6 @@
     }
 
-    #region Job Control methods
-    public void StartJobAsync(Job job, JobData jobData) {
+    #region Task Control methods
+    public void StartJobAsync(Task job, TaskData jobData) {
       SlaveJob slaveJob = null;
       slaveJobsLocker.EnterUpgradeableReadLock();
@@ -160,5 +160,5 @@
 
     #region Add/Remove SlaveJob
-    private void AddSlaveJob(Job job, SlaveJob slaveJob) {
+    private void AddSlaveJob(Task job, SlaveJob slaveJob) {
       slaveJobsLocker.EnterWriteLock();
       try {
@@ -217,5 +217,5 @@
       finally { slaveJobsLocker.ExitUpgradeableReadLock(); }
 
-      JobData jobData = null;
+      TaskData jobData = null;
       try {
         jobData = slaveJob.GetJobData();
@@ -240,5 +240,5 @@
       finally { slaveJobsLocker.ExitUpgradeableReadLock(); }
 
-      JobData jobData = null;
+      TaskData jobData = null;
       try {
         jobData = slaveJob.GetJobData();
@@ -263,5 +263,5 @@
       finally { slaveJobsLocker.ExitUpgradeableReadLock(); }
 
-      JobData jobData = null;
+      TaskData jobData = null;
       try {
         jobData = slaveJob.GetJobData();
@@ -294,20 +294,20 @@
     }
 
-    public event EventHandler<EventArgs<SlaveJob, JobData>> JobStopped;
-    private void OnJobStopped(SlaveJob slaveJob, JobData jobData) {
+    public event EventHandler<EventArgs<SlaveJob, TaskData>> JobStopped;
+    private void OnJobStopped(SlaveJob slaveJob, TaskData jobData) {
       var handler = JobStopped;
-      if (handler != null) handler(this, new EventArgs<SlaveJob, JobData>(slaveJob, jobData));
-    }
-
-    public event EventHandler<EventArgs<SlaveJob, JobData>> JobPaused;
-    private void OnJobPaused(SlaveJob slaveJob, JobData jobData) {
+      if (handler != null) handler(this, new EventArgs<SlaveJob, TaskData>(slaveJob, jobData));
+    }
+
+    public event EventHandler<EventArgs<SlaveJob, TaskData>> JobPaused;
+    private void OnJobPaused(SlaveJob slaveJob, TaskData jobData) {
       var handler = JobPaused;
-      if (handler != null) handler(this, new EventArgs<SlaveJob, JobData>(slaveJob, jobData));
-    }
-
-    public event EventHandler<EventArgs<Tuple<SlaveJob, JobData, Exception>>> JobFailed;
-    private void OnJobFailed(SlaveJob slaveJob, JobData jobData, Exception exception) {
+      if (handler != null) handler(this, new EventArgs<SlaveJob, TaskData>(slaveJob, jobData));
+    }
+
+    public event EventHandler<EventArgs<Tuple<SlaveJob, TaskData, Exception>>> JobFailed;
+    private void OnJobFailed(SlaveJob slaveJob, TaskData jobData, Exception exception) {
       var handler = JobFailed;
-      if (handler != null) handler(this, new EventArgs<Tuple<SlaveJob, JobData, Exception>>(new Tuple<SlaveJob, JobData, Exception>(slaveJob, jobData, exception)));
+      if (handler != null) handler(this, new EventArgs<Tuple<SlaveJob, TaskData, Exception>>(new Tuple<SlaveJob, TaskData, Exception>(slaveJob, jobData, exception)));
     }
 
Index: branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/Manager/PluginManager.cs
===================================================================
--- branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/Manager/PluginManager.cs	(revision 6712)
+++ branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/Manager/PluginManager.cs	(revision 6721)
@@ -135,5 +135,5 @@
     /// then copies the required plugins for the job.
     /// </summary>        
-    public void PreparePlugins(Job job, out string configFileName) {
+    public void PreparePlugins(Task job, out string configFileName) {
       lock (locker) {
         log.LogMessage("Fetching plugins for job " + job.Id);
Index: branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/SlaveJob.cs
===================================================================
--- branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/SlaveJob.cs	(revision 6712)
+++ branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/SlaveJob.cs	(revision 6721)
@@ -63,5 +63,5 @@
     }
 
-    public void StartJobAsync(Job job, JobData jobData) {
+    public void StartJobAsync(Task job, TaskData jobData) {
       try {
         this.JobId = job.Id;
@@ -86,5 +86,5 @@
     }
 
-    private void Prepare(Job job) {
+    private void Prepare(Task job) {
       string pluginDir = Path.Combine(pluginManager.PluginTempBaseDir, job.Id.ToString());
       string configFileName;
@@ -94,5 +94,5 @@
     }
 
-    private AppDomain CreateAppDomain(Job job, String pluginDir, string configFileName) {
+    private AppDomain CreateAppDomain(Task job, String pluginDir, string configFileName) {
       if (job.IsPrivileged) {
         appDomain = SandboxManager.CreateAndInitPrivilegedSandbox(job.Id.ToString(), pluginDir, Path.Combine(pluginDir, configFileName));
@@ -111,5 +111,5 @@
     }
 
-    private void StartJobInAppDomain(JobData jobData) {
+    private void StartJobInAppDomain(TaskData jobData) {
       executor.Start(jobData.Data);
       waitForStartBeforeKillSem.Release();
@@ -118,5 +118,5 @@
 
     public void DisposeAppDomain() {
-      log.LogMessage(string.Format("Shutting down Appdomain for Job {0}", JobId));
+      log.LogMessage(string.Format("Shutting down Appdomain for Task {0}", JobId));
       StopExecutorMonitoringThread();
 
@@ -154,5 +154,5 @@
     }
 
-    public JobData GetJobData() {
+    public TaskData GetJobData() {
       return executor.GetJobData();
     }
Index: branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/WcfService.cs
===================================================================
--- branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/WcfService.cs	(revision 6712)
+++ branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/WcfService.cs	(revision 6721)
@@ -54,16 +54,16 @@
     }
 
-    #region Job Methods
-    public Job GetJob(Guid jobId) {
+    #region Task Methods
+    public Task GetJob(Guid jobId) {
       return CallHiveService(s => s.GetJob(jobId));
     }
 
-    public void UpdateJob(Job job) {
+    public void UpdateJob(Task job) {
       CallHiveService(s => s.UpdateJob(job));
     }
     #endregion
 
-    #region JobData Methods
-    public JobData GetJobData(Guid jobId) {
+    #region TaskData Methods
+    public TaskData GetJobData(Guid jobId) {
       return CallHiveService(s => s.GetJobData(jobId));
     }
@@ -72,8 +72,8 @@
     /// Uploads the jobData and sets a new jobState (while correctly setting Transferring state)
     /// </summary>
-    public void UpdateJobData(Job job, JobData jobData, Guid slaveId, JobState state, string exception = "") {
+    public void UpdateJobData(Task job, TaskData jobData, Guid slaveId, TaskState state, string exception = "") {
       CallHiveService(service => {
         service.UpdateJob(job);
-        job = service.UpdateJobState(job.Id, JobState.Transferring, slaveId, null, null);
+        job = service.UpdateJobState(job.Id, TaskState.Transferring, slaveId, null, null);
         HiveClient.TryAndRepeat(() => {
           service.UpdateJobData(job, jobData);
@@ -83,5 +83,5 @@
     }
 
-    public Job UpdateJobState(Guid jobId, JobState jobState, string exception) {
+    public Task UpdateJobState(Guid jobId, TaskState jobState, string exception) {
       return CallHiveService(s => s.UpdateJobState(jobId, jobState, ConfigManager.Instance.GetClientInfo().Id, null, exception));
     }

Index: branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/Executor.cs
===================================================================
--- branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/Executor.cs	(revision 6712)
+++ branches/HeuristicLab.Hive-3.4/sources/HeuristicLab.Clients.Hive.Slave/3.3/Executor.cs	(revision 6721)
@@ -100,8 +100,8 @@
     public void Pause() {
       IsPausing = true;
       // wait until job is started. if this does not happen, the Job is null an we give up
       jobStartedSem.WaitOne(Settings.Default.ExecutorSemTimeouts);
       if (job == null) {
-        CurrentException = new Exception("Pausing job " + this.JobId + ": Job is null");
+        CurrentException = new Exception("Pausing job " + this.JobId + ": Task is null");
         executorQueue.AddMessage(ExecutorMessageType.ExceptionOccured);
         return;
@@ -123,8 +123,8 @@
     public void Stop() {
       IsStopping = true;
       // wait until job is started. if this does not happen, the Job is null an we give up
       jobStartedSem.WaitOne(Settings.Default.ExecutorSemTimeouts);
       if (job == null) {
-        CurrentException = new Exception("Stopping job " + this.JobId + ": Job is null");
+        CurrentException = new Exception("Stopping job " + this.JobId + ": Task is null");
         executorQueue.AddMessage(ExecutorMessageType.ExceptionOccured);
       }
@@ -157,5 +157,5 @@
     }
 
-    #region Job Events
+    #region Task Events
     private void Job_JobFailed(object sender, EventArgs e) {
       IsStopping = true;
@@ -185,21 +185,21 @@
     #endregion
 
-    public JobData GetJobData() {
+    public TaskData GetJobData() {
       if (jobDataInvalid) return null;
 
       if (job.ExecutionState == ExecutionState.Started) {
-        throw new InvalidStateException("Job is still running");
+        throw new InvalidStateException("Task is still running");
       } else {
-        JobData jobData = new JobData();
+        TaskData jobData = new TaskData();
         if (job == null) {
           //send empty job and save exception
-          jobData.Data = PersistenceUtil.Serialize(new JobData());
+          jobData.Data = PersistenceUtil.Serialize(new TaskData());
           if (CurrentException == null) {
-            CurrentException = new Exception("Job with id " + this.JobId + " is null, sending empty job");
+            CurrentException = new Exception("Task with id " + this.JobId + " is null, sending empty job");
           }
         } else {
           jobData.Data = PersistenceUtil.Serialize(job);
         }
-        jobData.JobId = JobId;
+        jobData.TaskId = JobId;
         return jobData;
       }
@@ -100,8 +100,8 @@
     public void Pause() {
       IsPausing = true;
-      // wait until job is started. if this does not happen, the Job is null an we give up
+      // wait until job is started. if this does not happen, the Task is null an we give up
       jobStartedSem.WaitOne(Settings.Default.ExecutorSemTimeouts);
       if (job == null) {
@@ -123,8 +123,8 @@
     public void Stop() {
       IsStopping = true;
-      // wait until job is started. if this does not happen, the Job is null an we give up
+      // wait until job is started. if this does not happen, the Task is null an we give up
       jobStartedSem.WaitOne(Settings.Default.ExecutorSemTimeouts);
       if (job == null) {